summaryrefslogtreecommitdiffstats
path: root/arts/kde/kvideowidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /arts/kde/kvideowidget.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'arts/kde/kvideowidget.h')
-rw-r--r--arts/kde/kvideowidget.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/arts/kde/kvideowidget.h b/arts/kde/kvideowidget.h
index f314267ca..0e3881a93 100644
--- a/arts/kde/kvideowidget.h
+++ b/arts/kde/kvideowidget.h
@@ -11,24 +11,24 @@
#ifndef ARTSKDE_KVIDEOWIDGET_H
#define ARTSKDE_KVIDEOWIDGET_H
-#include <qevent.h>
-#include <qimage.h>
-#include <qwidget.h>
+#include <tqevent.h>
+#include <tqimage.h>
+#include <tqwidget.h>
#include <kmedia2.h>
#include <kxmlguiclient.h>
-class KDE_ARTS_EXPORT KVideoWidget : public QWidget, virtual public KXMLGUIClient
+class KDE_ARTS_EXPORT KVideoWidget : public TQWidget, virtual public KXMLGUIClient
{
Q_OBJECT
public:
- KVideoWidget( KXMLGUIClient *clientParent, QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
- KVideoWidget( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ KVideoWidget( KXMLGUIClient *clientParent, TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ KVideoWidget( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
virtual ~KVideoWidget();
void embed( Arts::VideoPlayObject vpo );
- static QImage snapshot( Arts::VideoPlayObject vpo );
+ static TQImage snapshot( Arts::VideoPlayObject vpo );
bool isEmbedded();
bool isFullscreen();
@@ -36,14 +36,14 @@ public:
bool isNormalSize();
bool isDoubleSize();
- QSize sizeHint() const;
+ TQSize sizeHint() const;
virtual int heightForWidth ( int w ) const;
protected:
- virtual void mousePressEvent( QMouseEvent *event );
- virtual void mouseDoubleClickEvent( QMouseEvent *event);
- virtual void resizeEvent( QResizeEvent *event );
+ virtual void mousePressEvent( TQMouseEvent *event );
+ virtual void mouseDoubleClickEvent( TQMouseEvent *event);
+ virtual void resizeEvent( TQResizeEvent *event );
virtual bool x11Event( XEvent *event );
public slots:
@@ -63,17 +63,17 @@ protected slots:
signals:
void adaptSize( int width, int height );
- void mouseButtonPressed( int type, const QPoint &, int state );
- void mouseButtonDoubleClick( const QPoint &, int state );
+ void mouseButtonPressed( int type, const TQPoint &, int state );
+ void mouseButtonDoubleClick( const TQPoint &, int state );
/**
* @deprecated
* use mouseButtonPressed( int type, const QPoint & ) instead.
*/
- void rightButtonPressed( const QPoint & );
+ void rightButtonPressed( const TQPoint & );
private:
void init(void);
- QWidget *fullscreenWidget;
+ TQWidget *fullscreenWidget;
int videoWidth;
int videoHeight;
Arts::VideoPlayObject poVideo;
@@ -63,17 +63,17 @@ protected slots:
/**
* @deprecated
- * use mouseButtonPressed( int type, const QPoint & ) instead.
+ * use mouseButtonPressed( int type, const TQPoint & ) instead.
*/